@@ -1,7 +1,7 @@
 #
 # This file is part of Config-Model-Systemd
 #
-# This software is Copyright (c) 2015-2020 by Dominique Dumont.
+# This software is Copyright (c) 2008-2022 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
@@ -17,7 +17,7 @@ return [
       {
         'type' => 'leaf',
         'value_type' => 'uniline',
-        'warn' => 'Unknown parameter'
+        'warn' => 'Unexpected systemd parameter. Please contact cme author to update systemd model.'
       }
     ],
     'class_description' => 'A unit configuration file whose name ends in
@@ -91,8 +91,8 @@ example through C<PrivateNetwork>, see
 L<systemd.exec(5)>), receiving only
 the sockets configured through socket-activation from the host\'s namespace. In such a set-up communication within
 the host\'s network namespace is only permitted through the activation sockets passed in while all sockets allocated
-from the service code itself will be associated with the service\'s own namespace, and thus possibly subject to a a
-much more restrictive configuration.
+from the service code itself will be associated with the service\'s own namespace, and thus possibly subject to a
+restrictive configuration.
 This configuration class was generated from systemd documentation.
 by L<parse-man.pl|https://github.com/dod38fr/config-model-systemd/contrib/parse-man.pl>
 ',
@@ -354,7 +354,7 @@ below.',
           'value_type' => 'uniline'
         },
         'description' => 'Specifies a file system FIFO (see L<fifo(7)> for
-details) to listen on.  This expects an absolute file system path as argument.  Behavior otherwise is
+details) to listen on.	This expects an absolute file system path as argument.	Behavior otherwise is
 very similar to the C<ListenDatagram> directive above.',
         'type' => 'list'
       },
@@ -409,7 +409,7 @@ inherited between processes.',
           'value_type' => 'uniline'
         },
         'description' => 'Specifies a L<USB
-FunctionFS|https://www.kernel.org/doc/Documentation/usb/functionfs.txt> endpoints location to listen on, for
+FunctionFS|https://docs.kernel.org/usb/functionfs.html> endpoints location to listen on, for
 implementation of USB gadget functions. This expects an
 absolute file system path of a FunctionFS mount point as the argument.
 Behavior otherwise is very similar to the C<ListenFIFO>
@@ -522,36 +522,31 @@ notation. Defaults to 0755.',
       },
       'Accept',
       {
-        'description' => 'Takes a boolean argument. If yes, a service
-instance is spawned for each incoming connection and only the
-connection socket is passed to it. If no, all listening
-sockets themselves are passed to the started service unit, and
-only one service unit is spawned for all connections (also see
-above). This value is ignored for datagram sockets and FIFOs
-where a single service unit unconditionally handles all
-incoming traffic. Defaults to C<no>. For
-performance reasons, it is recommended to write new daemons
-only in a way that is suitable for
-C<Accept=no>. A daemon listening on an
-C<AF_UNIX> socket may, but does not need to,
-call
-L<close(2)>
-on the received socket before exiting. However, it must not
-unlink the socket from a file system. It should not invoke
-L<shutdown(2)>
-on sockets it got with C<Accept=no>, but it
-may do so for sockets it got with
-C<Accept=yes> set. Setting
-C<Accept=yes> is mostly useful to allow
-daemons designed for usage with
-L<inetd(8)>
-to work unmodified with systemd socket
-activation.
+        'description' => 'Takes a boolean argument. If yes, a service instance is spawned for each incoming
+connection and only the connection socket is passed to it. If no, all listening sockets themselves
+are passed to the started service unit, and only one service unit is spawned for all connections
+(also see above). This value is ignored for datagram sockets and FIFOs where a single service unit
+unconditionally handles all incoming traffic. Defaults to C<no>. For performance
+reasons, it is recommended to write new daemons only in a way that is suitable for
+C<Accept=no>. A daemon listening on an C<AF_UNIX> socket may, but
+does not need to, call
+L<close(2)> on the
+received socket before exiting. However, it must not unlink the socket from a file system. It should
+not invoke
+L<shutdown(2)> on
+sockets it got with C<Accept=no>, but it may do so for sockets it got with
+C<Accept=yes> set. Setting C<Accept=yes> is mostly useful to allow
+daemons designed for usage with L<inetd(8)> to work
+unmodified with systemd socket activation.
 
 For IPv4 and IPv6 connections, the C<REMOTE_ADDR> environment variable will
 contain the remote IP address, and C<REMOTE_PORT> will contain the remote port. This
 is the same as the format used by CGI. For C<SOCK_RAW>, the port is the IP
-protocol.',
+protocol.
+
+It is recommended to set C<CollectMode=inactive-or-failed> for service
+instances activated via C<Accept=yes>, to ensure that failed connection services are
+cleaned up and released from memory, and do not accumulate.',
         'type' => 'leaf',
         'value_type' => 'boolean',
         'write_as' => [
@@ -783,7 +778,7 @@ C<security.SMACK64IPIN> and
 C<security.SMACK64IPOUT>, respectively, i.e.
 the security label of the FIFO, or the security label for the
 incoming or outgoing connections of the socket, respectively.
-See L<Smack.txt|https://www.kernel.org/doc/Documentation/security/Smack.txt>
+See L<Smack|https://docs.kernel.org/admin-guide/LSM/Smack.html>
 for details.',
         'type' => 'leaf',
         'value_type' => 'uniline'
@@ -796,7 +791,7 @@ C<security.SMACK64IPIN> and
 C<security.SMACK64IPOUT>, respectively, i.e.
 the security label of the FIFO, or the security label for the
 incoming or outgoing connections of the socket, respectively.
-See L<Smack.txt|https://www.kernel.org/doc/Documentation/security/Smack.txt>
+See L<Smack|https://docs.kernel.org/admin-guide/LSM/Smack.html>
 for details.',
         'type' => 'leaf',
         'value_type' => 'uniline'
@@ -809,7 +804,7 @@ C<security.SMACK64IPIN> and
 C<security.SMACK64IPOUT>, respectively, i.e.
 the security label of the FIFO, or the security label for the
 incoming or outgoing connections of the socket, respectively.
-See L<Smack.txt|https://www.kernel.org/doc/Documentation/security/Smack.txt>
+See L<Smack|https://docs.kernel.org/admin-guide/LSM/Smack.html>
 for details.',
         'type' => 'leaf',
         'value_type' => 'uniline'
@@ -824,10 +819,12 @@ from the information provided by the peer. Other parts of the
 resulting SELinux context originate from either the target
 binary that is effectively triggered by socket unit or from
 the value of the C<SELinuxContext> option.
-This configuration option only affects sockets with
-C<Accept> mode set to
-C<yes>. Also note that this option is useful
-only when MLS/MCS SELinux policy is deployed. Defaults to
+This configuration option applies only when activated service
+is passed in single socket file descriptor, i.e. service
+instances that have standard input connected to a socket or
+services triggered by exactly one socket unit. Also note
+that this option is useful only when MLS/MCS SELinux policy
+is deployed. Defaults to
 C<false>.',
         'type' => 'leaf',
         'value_type' => 'boolean',
@@ -1106,7 +1103,7 @@ suffix.',
       },
       'TriggerLimitIntervalSec',
       {
-        'description' => "Configures a limit on how often this socket unit my be activated within a specific time
+        'description' => "Configures a limit on how often this socket unit may be activated within a specific time
 interval. The C<TriggerLimitIntervalSec> may be used to configure the length of the time
 interval in the usual time units C<us>, C<ms>, C<s>,
 C<min>, C<h>, \x{2026} and defaults to 2s (See
@@ -1122,7 +1119,7 @@ limit is enforced before the service activation is enqueued.",
       },
       'TriggerLimitBurst',
       {
-        'description' => "Configures a limit on how often this socket unit my be activated within a specific time
+        'description' => "Configures a limit on how often this socket unit may be activated within a specific time
 interval. The C<TriggerLimitIntervalSec> may be used to configure the length of the time
 interval in the usual time units C<us>, C<ms>, C<s>,
 C<min>, C<h>, \x{2026} and defaults to 2s (See
@@ -1137,7 +1134,7 @@ limit is enforced before the service activation is enqueued.",
         'value_type' => 'uniline'
       }
     ],
-    'generated_by' => 'parse-man.pl from systemd 247 doc',
+    'generated_by' => 'parse-man.pl from systemd 252 doc',
     'license' => 'LGPLv2.1+',
     'name' => 'Systemd::Section::Socket'
   }
