@@ -1,7 +1,7 @@
 #
 # This file is part of Config-Model-Systemd
 #
-# This software is Copyright (c) 2008-2021 by Dominique Dumont.
+# This software is Copyright (c) 2008-2022 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
@@ -68,13 +68,11 @@ type suffix). The name of the full unit is formed by inserting the instance name
 C<\@> and the unit type suffix. In the unit file itself, the instance parameter may be
 referred to using C<%i> and other specifiers, see below.
 
-Unit files may contain additional options on top of those
-listed here. If systemd encounters an unknown option, it will
-write a warning log message but continue loading the unit. If an
-option or section name is prefixed with C<X->, it is
-ignored completely by systemd. Options within an ignored section
-do not need the prefix. Applications may use this to include
-additional information in the unit files.
+Unit files may contain additional options on top of those listed here. If systemd encounters an
+unknown option, it will write a warning log message but continue loading the unit. If an option or
+section name is prefixed with C<X->, it is ignored completely by systemd. Options within an
+ignored section do not need the prefix. Applications may use this to include additional information in
+the unit files. To access those options, applications need to parse the unit files on their own.
 
 Units can be aliased (have an alternative name), by creating a symlink from the new name to the
 existing name in one of the unit search paths. For example, C<systemd-networkd.service>
@@ -82,7 +80,7 @@ has the alias C<dbus-org.freedesktop.network1.service>, created during installat
 a symlink, so when systemd is asked through D-Bus to load
 C<dbus-org.freedesktop.network1.service>, it'll load
 C<systemd-networkd.service>. As another example, C<default.target> \x{2014}
-the default system target started at boot \x{2014} is commonly symlinked (aliased) to either
+the default system target started at boot \x{2014} is commonly aliased to either
 C<multi-user.target> or C<graphical.target> to select what is started
 by default. Alias names may be used in commands like disable,
 start, stop, status, and similar, and in all
@@ -98,8 +96,12 @@ another template (in which case the alias applies to all instances of the templa
 template instance (e.g. C<alias\@inst.service>) may be a symlink to different template
 (e.g. C<template\@inst.service>). In that case, just this specific instance is aliased,
 while other instances of the template (e.g. C<alias\@foo.service>,
-C<alias\@bar.service>) are not aliased. Those rule preserve the requirement that the
-instance (if any) is always uniquely defined for a given unit and all its aliases.
+C<alias\@bar.service>) are not aliased. Those rules preserve the requirement that the
+instance (if any) is always uniquely defined for a given unit and all its aliases. The target of alias
+symlink must point to a valid unit file location, i.e. the symlink target name must match the symlink
+source name as described, and the destination path must be in one of the unit search paths, see UNIT FILE
+LOAD PATH section below for more details. Note that the target file may not exist, i.e. the symlink may
+be dangling.
 
 Unit files may specify aliases through the C<Alias> directive in the [Install]
 section. When the unit is enabled, symlinks will be created for those names, and removed when the unit is
@@ -119,11 +121,18 @@ implicitly added as dependencies of type C<Wants> to the unit. Similar functiona
 exists for C<Requires> type dependencies as well, the directory suffix is
 C<.requires/> in this case. This functionality is useful to hook units into the
 start-up of other units, without having to modify their unit files. For details about the semantics of
-C<Wants>, see below. The preferred way to create symlinks in the
-C<.wants/> or C<.requires/> directory of a unit file is by embedding
-the dependency in [Install] section of the target unit, and creating the symlink in the file system with
-the enable or preset commands of
-L<systemctl(1)>.
+C<Wants> and C<Requires>, see below. The preferred way to create
+symlinks in the C<.wants/> or C<.requires/> directories is by
+specifying the dependency in [Install] section of the target unit, and creating the symlink in the file
+system with the enable or preset commands of
+L<systemctl(1)>.  The
+target can be a normal unit (either plain or a specific instance of a template unit). In case when the
+source unit is a template, the target can also be a template, in which case the instance will be
+\"propagated\" to the target unit to form a valid unit instance. The target of symlinks in
+C<.wants/> or C<.requires/> must thus point to a valid unit file
+location, i.e. the symlink target name must satisfy the described requirements, and the destination path
+must be in one of the unit search paths, see UNIT FILE LOAD PATH section below for more details. Note
+that the target file may not exist, i.e. the symlink may be dangling.
 
 Along with a unit file C<foo.service>, a \"drop-in\" directory
 C<foo.service.d/> may exist. All files with the suffix
@@ -221,13 +230,30 @@ would be used based on compilation options and current environment use
 
 
 
-Moreover, additional units might be loaded into systemd from
-directories not on the unit load path by creating a symlink pointing to a
-unit file in the directories. You can use systemctl link
-for this operation. See
-L<systemctl(1)>
-for its usage and precaution.
+Moreover, additional units might be loaded into systemd from directories not on the unit load path
+by creating a symlink pointing to a unit file in the directories. You can use systemctl
+link for this; see
+L<systemctl(1)>. The file
+system where the linked unit files are located must be accessible when systemd is started (e.g. anything
+underneath C</home/> or C</var/> is not allowed, unless those
+directories are located on the root file system).
 
+It is important to distinguish \"linked unit files\" from \"unit file aliases\": any symlink where the
+symlink target is within the unit load path becomes an alias: the source name and
+the target file name must satisfy specific constraints listed above in the discussion of aliases, but the
+symlink target doesn't have to exist, and in fact the symlink target path is not used, except to check
+whether the target is within the unit load path. In contrast, a symlink which goes outside of the unit
+load path signifies a linked unit file. The symlink is followed when loading the file, but the
+destination name is otherwise unused (and may even not be a valid unit file name). For example, symlinks
+C</etc/systemd/system/alias1.service> \x{2192} C<service1.service>,
+C</etc/systemd/system/alias2.service> \x{2192} C</usr/lib/systemd/service1.service>,
+C</etc/systemd/system/alias3.service> \x{2192} C</etc/systemd/system/service1.service>
+are all valid aliases and C<service1.service> will have
+four names, even if the unit file is located at
+C</run/systemd/system/service1.service>. In contrast,
+a symlink C</etc/systemd/system/link1.service> \x{2192} C<../link1_service_file>
+means that C<link1.service> is a \"linked unit\" and the contents of
+C</etc/systemd/link1_service_file> provide its configuration.
 
 Unit files may also include a number of C<Condition\x{2026}=> and C<Assert\x{2026}=> settings. Before the unit is started, systemd will verify that the
 specified conditions and asserts are true. If not, the starting of the unit will be (mostly silently)
@@ -253,7 +279,7 @@ condition settings (of any kind) will have no effect.
 
 The C<AssertArchitecture>, C<AssertVirtualization>, \x{2026} options
 are similar to conditions but cause the start job to fail (instead of being skipped). The failed check
-is logged. Units with failed conditions are considered to be in a clean state and will be garbage
+is logged. Units with unmet conditions are considered to be in a clean state and will be garbage
 collected if they are not referenced. This means that when queried, the condition failure may or may
 not show up in the state of the unit.
 
@@ -355,8 +381,8 @@ C<.requires/> directory accompanying the unit file.
 If this unit gets activated, the units listed will be activated as well. If one of
 the other units fails to activate, and an ordering dependency C<After> on the
 failing unit is set, this unit will not be started. Besides, with or without specifying
-C<After>, this unit will be stopped if one of the other units is explicitly
-stopped.
+C<After>, this unit will be stopped (or restarted) if one of the other units is
+explicitly stopped (or restarted).
 
 Often, it is a better choice to use C<Wants> instead of
 C<Requires> in order to achieve a system that is more robust when dealing with
@@ -409,7 +435,7 @@ a mount unit might be unmounted without involvement of the system and service ma
 When used in conjunction with C<After> on the same unit the behaviour of
 C<BindsTo> is even stronger. In this case, the unit bound to strictly has to be in active
 state for this unit to also be in active state. This not only means a unit bound to another unit that suddenly
-enters inactive state, but also one that is bound to another unit that gets skipped due to a failed condition
+enters inactive state, but also one that is bound to another unit that gets skipped due to an unmet condition
 check (such as C<ConditionPathExists>, C<ConditionPathIsSymbolicLink>, \x{2026} \x{2014}
 see below) will be stopped, should it be running. Hence, in many cases it is best to combine
 C<BindsTo> with C<After>.
@@ -443,7 +469,7 @@ dependency cannot be specified directly.",
       },
       'Upholds',
       {
-        'description' => 'Configures dependencies similar to C<Wants>, but as long a this unit
+        'description' => 'Configures dependencies similar to C<Wants>, but as long as this unit
 is up, all units listed in C<Upholds> are started whenever found to be inactive or
 failed, and no job is queued for them. While a C<Wants> dependency on another unit
 has a one-time effect when this units started, a C<Upholds> dependency on it has a
@@ -1019,10 +1045,8 @@ mark.',
           'type' => 'leaf',
           'value_type' => 'uniline'
         },
-        'description' => 'Check whether the system\'s firmware is of a certain type. Possible values are:
-C<uefi> (for systems with EFI),
-C<device-tree> (for systems with a device tree) and
-C<device-tree-compatible(xyz)> (for systems with a device tree that is compatible to C<xyz>).',
+        'description' => 'Check whether the system\'s firmware is of a certain type. The following values are
+possible:',
         'type' => 'list'
       },
       'ConditionVirtualization',
@@ -1049,6 +1073,7 @@ C<bochs>,
 C<uml>,
 C<bhyve>,
 C<qnx>,
+C<apple>,
 C<openvz>,
 C<lxc>,
 C<lxc-libvirt>,
@@ -1107,12 +1132,13 @@ is invoked as payload of a container manager, in which case the command line of
           'value_type' => 'uniline'
         },
         'description' => 'C<ConditionKernelVersion> may be used to check whether the kernel
-version (as reported by uname -r) matches a certain expression (or if prefixed
-with the exclamation mark does not match it). The argument must be a list of (potentially quoted)
-expressions.  For each of the expressions, if it starts with one of C<<>,
-C<<=>, C<=>, C<!=>, C<>=>,
-C<>> a relative version comparison is done, otherwise the specified string is
-matched with shell-style globs.
+version (as reported by uname -r) matches a certain expression, or if prefixed
+with the exclamation mark, does not match. The argument must be a list of (potentially quoted)
+expressions. Each expression starts with one of C<=> or C<!=> for
+string comparisons, C<< < >>, C<< <= >>, C<==>,
+C<< <> >>, C<< >= >>, C<< > >> for version
+comparisons, or C<$=>, C<!$=> for a shell-style glob match. If no
+operator is specified, C<$=> is implied.
 
 Note that using the kernel version string is an unreliable way to determine which features
 are supported by a kernel, because of the widespread practice of backporting drivers, features, and
@@ -1121,6 +1147,22 @@ is inherently unportable and should not be used for units which may be used on d
 distributions.',
         'type' => 'list'
       },
+      'ConditionCredential',
+      {
+        'cargo' => {
+          'type' => 'leaf',
+          'value_type' => 'uniline'
+        },
+        'description' => 'C<ConditionCredential> may be used to check whether a credential
+by the specified name was passed into the service manager. See L<System and Service
+Credentials|https://systemd.io/CREDENTIALS> for details about
+credentials. If used in services for the system service manager this may be used to conditionalize
+services based on system credentials passed in. If used in services for the per-user service
+manager this may be used to conditionalize services based on credentials passed into the
+C<unit@.service> service instance belonging to the user. The argument must be a
+valid credential name.',
+        'type' => 'list'
+      },
       'ConditionEnvironment',
       {
         'cargo' => {
@@ -1238,15 +1280,18 @@ happen.',
           ]
         },
         'description' => 'Takes a boolean argument. This condition may be used to conditionalize units on
-whether the system is booting up for the first time.  This roughly means that C</etc/>
-is unpopulated (for details, see "First Boot Semantics" in
+whether the system is booting up for the first time. This roughly means that C</etc/>
+was unpopulated when the system started booting (for details, see "First Boot Semantics" in
 L<machine-id(5)>).
-This may be used to populate C</etc/> on the first boot after factory reset, or
-when a new system instance boots up for the first time.
+First boot is considered finished (this condition will evaluate as false) after the manager
+has finished the startup phase.
+
+This condition may be used to populate C</etc/> on the first boot after
+factory reset, or when a new system instance boots up for the first time.
 
 For robustness, units with C<ConditionFirstBoot=yes> should order themselves
 before C<first-boot-complete.target> and pull in this passive target with
-C<Wants>.  This ensures that in a case of an aborted first boot, these units will
+C<Wants>. This ensures that in a case of an aborted first boot, these units will
 be re-run during the next system startup.
 
 If the C<systemd.condition-first-boot=> option is specified on the kernel
@@ -1402,23 +1447,14 @@ C<@system>.',
           'value_type' => 'uniline'
         },
         'description' => 'Check whether given cgroup controllers (e.g. C<cpu>) are available
-for use on the system or whether the legacy v1 cgroup or the modern v2 cgroup hierarchy is used.
+for use on the system.
 
 Multiple controllers may be passed with a space separating them; in this case the condition
 will only pass if all listed controllers are available for use. Controllers unknown to systemd are
-ignored. Valid controllers are C<cpu>, C<cpuacct>,
-C<io>, C<blkio>, C<memory>,
-C<devices>, and C<pids>. Even if available in the kernel, a
-particular controller may not be available if it was disabled on the kernel command line with
-C<cgroup_disable=controller>.
-
-Alternatively, two special strings C<v1> and C<v2> may be
-specified (without any controller names). C<v2> will pass if the unified v2 cgroup
-hierarchy is used, and C<v1> will pass if the legacy v1 hierarchy or the hybrid
-hierarchy are used (see the discussion of C<systemd.unified_cgroup_hierarchy> and
-C<systemd.legacy_systemd_cgroup_controller> in
-L<systemd.service(5)>
-for more information).',
+ignored. Valid controllers are C<cpu>, C<cpuset>,
+C<io>, C<memory>, and C<pids>. Even if available in
+the kernel, a particular controller may not be available if it was disabled on the kernel command
+line with C<cgroup_disable=controller>.',
         'type' => 'list'
       },
       'ConditionMemory',
@@ -1429,10 +1465,11 @@ for more information).',
         },
         'description' => 'Verify that the specified amount of system memory is available to the current
 system. Takes a memory size in bytes as argument, optionally prefixed with a comparison operator
-C<<>, C<<=>, C<=>, C<!=>,
-C<>=>, C<>>. On bare-metal systems compares the amount of
-physical memory in the system with the specified size, adhering to the specified comparison
-operator. In containers compares the amount of memory assigned to the container instead.',
+C<< < >>, C<< <= >>, C<=> (or C<==>),
+C<!=> (or C<< <> >>), C<< >= >>,
+C<< > >>. On bare-metal systems compares the amount of physical memory in the system
+with the specified size, adhering to the specified comparison operator. In containers compares the
+amount of memory assigned to the container instead.',
         'type' => 'list'
       },
       'ConditionCPUs',
@@ -1443,13 +1480,14 @@ operator. In containers compares the amount of memory assigned to the container
         },
         'description' => 'Verify that the specified number of CPUs is available to the current system. Takes
 a number of CPUs as argument, optionally prefixed with a comparison operator
-C<<>, C<<=>, C<=>, C<!=>,
-C<>=>, C<>>. Compares the number of CPUs in the CPU affinity
-mask configured of the service manager itself with the specified number, adhering to the specified
-comparison operator. On physical systems the number of CPUs in the affinity mask of the service
-manager usually matches the number of physical CPUs, but in special and virtual environments might
-differ. In particular, in containers the affinity mask usually matches the number of CPUs assigned
-to the container and not the physically available ones.',
+C<< < >>, C<< <= >>, C<=> (or C<==>),
+C<!=> (or C<< <> >>), C<< >= >>,
+C<< > >>. Compares the number of CPUs in the CPU affinity mask configured of the
+service manager itself with the specified number, adhering to the specified comparison operator. On
+physical systems the number of CPUs in the affinity mask of the service manager usually matches the
+number of physical CPUs, but in special and virtual environments might differ. In particular, in
+containers the affinity mask usually matches the number of CPUs assigned to the container and not
+the physically available ones.',
         'type' => 'list'
       },
       'ConditionCPUFeature',
@@ -1525,10 +1563,78 @@ C<constant_tsc>.',
         'description' => 'Verify that a specific C<key=value> pair is set in the host\'s
 L<os-release(5)>.
 
-Other than exact matching with C<=>, and C<!=>, relative
-comparisons are supported for versioned parameters (e.g. C<VERSION_ID>). The
-comparator can be one of C<<>, C<<=>, C<=>,
-C<!=>, C<>=> and C<>>.',
+Other than exact string matching (with C<=> and C<!=>),
+relative comparisons are supported for versioned parameters (e.g. C<VERSION_ID>;
+with C<< < >>, C<< <= >>, C<==>,
+C<< <> >>, C<< >= >>, C<< > >>), and shell-style
+wildcard comparisons (C<*>, C<?>, C<[]>) are
+supported with the C<$=> (match) and C<!$=> (non-match).',
+        'type' => 'list'
+      },
+      'ConditionMemoryPressure',
+      {
+        'cargo' => {
+          'type' => 'leaf',
+          'value_type' => 'uniline'
+        },
+        'description' => 'Verify that the overall system (memory, CPU or IO) pressure is below or equal to a threshold.
+This setting takes a threshold value as argument. It can be specified as a simple percentage value,
+suffixed with C<%>, in which case the pressure will be measured as an average over the last
+five minutes before the attempt to start the unit is performed.
+Alternatively, the average timespan can also be specified using C</> as a separator, for
+example: C<10%/1min>. The supported timespans match what the kernel provides, and are
+limited to C<10sec>, C<1min> and C<5min>. The
+C<full> PSI will be checked first, and if not found C<some> will be
+checked. For more details, see the documentation on L<PSI (Pressure Stall Information)
+|https://docs.kernel.org/accounting/psi.html>.
+
+Optionally, the threshold value can be prefixed with the slice unit under which the pressure will be checked,
+followed by a C<:>. If the slice unit is not specified, the overall system pressure will be measured,
+instead of a particular cgroup\'s.',
+        'type' => 'list'
+      },
+      'ConditionCPUPressure',
+      {
+        'cargo' => {
+          'type' => 'leaf',
+          'value_type' => 'uniline'
+        },
+        'description' => 'Verify that the overall system (memory, CPU or IO) pressure is below or equal to a threshold.
+This setting takes a threshold value as argument. It can be specified as a simple percentage value,
+suffixed with C<%>, in which case the pressure will be measured as an average over the last
+five minutes before the attempt to start the unit is performed.
+Alternatively, the average timespan can also be specified using C</> as a separator, for
+example: C<10%/1min>. The supported timespans match what the kernel provides, and are
+limited to C<10sec>, C<1min> and C<5min>. The
+C<full> PSI will be checked first, and if not found C<some> will be
+checked. For more details, see the documentation on L<PSI (Pressure Stall Information)
+|https://docs.kernel.org/accounting/psi.html>.
+
+Optionally, the threshold value can be prefixed with the slice unit under which the pressure will be checked,
+followed by a C<:>. If the slice unit is not specified, the overall system pressure will be measured,
+instead of a particular cgroup\'s.',
+        'type' => 'list'
+      },
+      'ConditionIOPressure',
+      {
+        'cargo' => {
+          'type' => 'leaf',
+          'value_type' => 'uniline'
+        },
+        'description' => 'Verify that the overall system (memory, CPU or IO) pressure is below or equal to a threshold.
+This setting takes a threshold value as argument. It can be specified as a simple percentage value,
+suffixed with C<%>, in which case the pressure will be measured as an average over the last
+five minutes before the attempt to start the unit is performed.
+Alternatively, the average timespan can also be specified using C</> as a separator, for
+example: C<10%/1min>. The supported timespans match what the kernel provides, and are
+limited to C<10sec>, C<1min> and C<5min>. The
+C<full> PSI will be checked first, and if not found C<some> will be
+checked. For more details, see the documentation on L<PSI (Pressure Stall Information)
+|https://docs.kernel.org/accounting/psi.html>.
+
+Optionally, the threshold value can be prefixed with the slice unit under which the pressure will be checked,
+followed by a C<:>. If the slice unit is not specified, the overall system pressure will be measured,
+instead of a particular cgroup\'s.',
         'type' => 'list'
       },
       'AssertArchitecture',
@@ -1597,6 +1703,20 @@ loudly). Note that hitting a configured assertion does not cause the unit to ent
 C<failed> state (or in fact result in any state change of the unit), it affects
 only the job queued for it. Use assertion expressions for units that cannot operate when specific
 requirements are not met, and when this is something the administrator or user should look
+into.",
+        'type' => 'leaf',
+        'value_type' => 'uniline'
+      },
+      'AssertCredential',
+      {
+        'description' => "Similar to the C<ConditionArchitecture>,
+C<ConditionVirtualization>, \x{2026}, condition settings described above, these settings
+add assertion checks to the start-up of the unit. However, unlike the conditions settings, any
+assertion setting that is not met results in failure of the start job (which means this is logged
+loudly). Note that hitting a configured assertion does not cause the unit to enter the
+C<failed> state (or in fact result in any state change of the unit), it affects
+only the job queued for it. Use assertion expressions for units that cannot operate when specific
+requirements are not met, and when this is something the administrator or user should look
 into.",
         'type' => 'leaf',
         'value_type' => 'uniline'
@@ -1891,6 +2011,20 @@ loudly). Note that hitting a configured assertion does not cause the unit to ent
 C<failed> state (or in fact result in any state change of the unit), it affects
 only the job queued for it. Use assertion expressions for units that cannot operate when specific
 requirements are not met, and when this is something the administrator or user should look
+into.",
+        'type' => 'leaf',
+        'value_type' => 'uniline'
+      },
+      'AssertCPUFeature',
+      {
+        'description' => "Similar to the C<ConditionArchitecture>,
+C<ConditionVirtualization>, \x{2026}, condition settings described above, these settings
+add assertion checks to the start-up of the unit. However, unlike the conditions settings, any
+assertion setting that is not met results in failure of the start job (which means this is logged
+loudly). Note that hitting a configured assertion does not cause the unit to enter the
+C<failed> state (or in fact result in any state change of the unit), it affects
+only the job queued for it. Use assertion expressions for units that cannot operate when specific
+requirements are not met, and when this is something the administrator or user should look
 into.",
         'type' => 'leaf',
         'value_type' => 'uniline'
@@ -1905,6 +2039,48 @@ loudly). Note that hitting a configured assertion does not cause the unit to ent
 C<failed> state (or in fact result in any state change of the unit), it affects
 only the job queued for it. Use assertion expressions for units that cannot operate when specific
 requirements are not met, and when this is something the administrator or user should look
+into.",
+        'type' => 'leaf',
+        'value_type' => 'uniline'
+      },
+      'AssertMemoryPressure',
+      {
+        'description' => "Similar to the C<ConditionArchitecture>,
+C<ConditionVirtualization>, \x{2026}, condition settings described above, these settings
+add assertion checks to the start-up of the unit. However, unlike the conditions settings, any
+assertion setting that is not met results in failure of the start job (which means this is logged
+loudly). Note that hitting a configured assertion does not cause the unit to enter the
+C<failed> state (or in fact result in any state change of the unit), it affects
+only the job queued for it. Use assertion expressions for units that cannot operate when specific
+requirements are not met, and when this is something the administrator or user should look
+into.",
+        'type' => 'leaf',
+        'value_type' => 'uniline'
+      },
+      'AssertCPUPressure',
+      {
+        'description' => "Similar to the C<ConditionArchitecture>,
+C<ConditionVirtualization>, \x{2026}, condition settings described above, these settings
+add assertion checks to the start-up of the unit. However, unlike the conditions settings, any
+assertion setting that is not met results in failure of the start job (which means this is logged
+loudly). Note that hitting a configured assertion does not cause the unit to enter the
+C<failed> state (or in fact result in any state change of the unit), it affects
+only the job queued for it. Use assertion expressions for units that cannot operate when specific
+requirements are not met, and when this is something the administrator or user should look
+into.",
+        'type' => 'leaf',
+        'value_type' => 'uniline'
+      },
+      'AssertIOPressure',
+      {
+        'description' => "Similar to the C<ConditionArchitecture>,
+C<ConditionVirtualization>, \x{2026}, condition settings described above, these settings
+add assertion checks to the start-up of the unit. However, unlike the conditions settings, any
+assertion setting that is not met results in failure of the start job (which means this is logged
+loudly). Note that hitting a configured assertion does not cause the unit to enter the
+C<failed> state (or in fact result in any state change of the unit), it affects
+only the job queued for it. Use assertion expressions for units that cannot operate when specific
+requirements are not met, and when this is something the administrator or user should look
 into.",
         'type' => 'leaf',
         'value_type' => 'uniline'
@@ -1924,7 +2100,7 @@ into.",
         'warn' => 'OnFailureIsolate is now OnFailureJobMode.'
       }
     ],
-    'generated_by' => 'parse-man.pl from systemd 249 doc',
+    'generated_by' => 'parse-man.pl from systemd 252 doc',
     'license' => 'LGPLv2.1+',
     'name' => 'Systemd::Section::Unit'
   }
